@@ -56,6 +56,8 @@ static int handler(void* setting, const char* section, const char* name, const c
         config->threshold_pitch = deg_to_rad(atoi(value));
     } else if (MATCH("control", "profile")) {
         config->profile = strdup(value);
+    } else if (MATCH("control", "turtle")) {
+        config->turtle = atoi(value);
     }
 }
 
@@ -153,7 +155,7 @@ int main(int argc, char **argv)
   orientation current, previous;
 
   unsigned int read_errors = 0;
-  unsigned long frames = 1, events = 0;
+  unsigned long frames = 1, events = 0, turtle_timer = 0, status_poll = 0;
 
   struct timespec sample_interval;
   struct stat cfg_stat;
@@ -172,7 +174,10 @@ int main(int argc, char **argv)
 
     read_errors+= do_poll(config.samples, &sample_interval, &ax, &ay, &az);
     frames++;
-    if (!(frames % 240)){ // infrequently check...
+
+    // Monitor the state of the config file and trigger file infrequently
+    if (!(frames % 10) && status_poll < time(0)-5){
+      status_poll = time(0);
       if (trigger_filename[0] && access(trigger_filename, F_OK)) break; // if trigger file is gone, quit...
       stat(config_file, &cfg_stat);
       if (cfg_stat.st_mtime > config.freshness) { // or if configuration has been modified...
@@ -185,7 +190,28 @@ int main(int argc, char **argv)
         sample_interval.tv_nsec = ONE_SECOND / (config.frame_rate * config.samples);
       }
     }
+
+    // Handle turtle mode if user has flipped phone upside down
+    if (config.turtle && az > 750) { // TODO: may need filtering to avoid accidental activation during motion if poll time is short
+      turtle_timer = time(0); // Not used, but could e.g. shutdown service if left upside down
+      sample_interval.tv_nsec = ONE_SECOND * 3lu;
+      while (!do_poll(1, &sample_interval, &ax, &ay, &az) && az > 100) // Poll slowly until flipped face-up again.
+        if (trigger_filename[0] && access(trigger_filename, F_OK)) break; // Don't forget to check for shutdown
+      if (config.turtle < 0) { 
+        config.turtle = 1; // Turtle enabled but inactive
+        sample_interval.tv_nsec = ONE_SECOND / (config.frame_rate * config.samples);
+      } else { 
+        // Center joystick before turtling
+        do_uinput(uinput_fd, ABS_X, 0, EV_ABS);
+        do_uinput(uinput_fd, ABS_Y, 0, EV_ABS);
+        config.turtle = -1; 
+        sample_interval.tv_nsec = ONE_SECOND / 2.5;
+      }
+    }
+    if (config.turtle == -1) continue; //skip events in turtle mode
  
+    // Calculate tilt and fire joystick events
+    //
     // TODO: Keep state and/or watch total acceleration to subtract out "gestures". Also, the math could probably use some work.
     acc = sqrtf(((long)ax)*ax + ((long)ay)*ay + ((long)az)*az);  //Use long to avoid overflow when squaring ~1000 to get vector length!
 
