@@ -9,7 +9,7 @@
 #define VERSION "0.0.3"
 #define MAX_AXIS 0xFFFF		// SDL's joystick axis is stored in 16 bit int
 #define PI 3.1415
-#define ONE_SECOND 1000000000	// for nanosleep			
+#define ONE_SECOND 1000000000lu	// for nanosleep			
 
 int debug=0;
 
@@ -28,6 +28,7 @@ typedef struct
 	int version;	// cfg file format version
 	int samples; 	// Samples to average each event
 	int frame_rate;	// number of event-generating timesteps per second
+	int turtle;	// Turtle goes to sleep when upside down, and is turned on and off in the process.
 
 	int flip_pitch;	// -1=> tilt forward is up; 1=> tilt forward is down
 	float offset_pitch;	// The amount of backwards tilt to the neutral position (from flat, face up)
